##########################################################################
# έp (@)                                                            #
# Anderson et al., Statistics for Business & Economics (14th Edition)    #
# Chapter 8: Interval Estimation                                         #
# d~ ߬FvjǲέpǨt                                            #
# http://www.hmwu.idv.tw/                                                #
##########################################################################



######################################
# 8.1 Population Mean: sigma Known   #
######################################

# X1, X2, ..., Xn ~ N(mu, sigma^2), 100*(1-alpha)% CI for mu
n <- 100
xbar <- 82
sigma <- 20 # sigma Known

sigma.xbar <- sigma/sqrt(n)
sigma.xbar 
alpha <- 0.05  # 95% significance level
qnorm(alpha/2)
z.alpha <- qnorm(1 - alpha/2)
z.alpha

# Margin of Error 
margin.error <- z.alpha * sigma.xbar
c(-margin.error, margin.error)

# 100(1 - alpha)%  confidence coefficient for population mean
c(xbar - margin.error, xbar + margin.error)


# Chapter 7: Lloyds example
# (a) Each week Lloyds Department Store selects a simple random sample of 100
#     customers in order to learn about the amount spent per shopping trip.
# (b) With x representing the amount spent per shopping trip, the sample mean x
#     provides a point estimate of g, the mean amount spent per shopping trip
#     for the population of all Lloyds customers.
# (c) Based on the historical data, Lloyds now assumes a known value of sigma = $20
#     for the population standard deviation and the population follows a normal
#     distribution.

# if you read excel 
# library(readxl)
LloydS <- read_excel("data/chap08/LloydS.xlsx")

# if you read csv
# LloydS <- read.csv("data/chap08/LloydS.csv")
# str(LloydS)
# LloydS$"Amount Spent" <- LloydS$Amount.Spent

str(LloydS)
head(LloydS)
tail(LloydS)
N <- length(LloydS$"Amount Spent")
N
n <- 30
id <- sample(1:N, n)
xbar <- mean(LloydS$"Amount Spent"[id])
c(xbar - margin.error, xbar + margin.error)



# suppose true mean mu = mean(LloydS$"Amount Spent")
count <- numeric(10000)
mu <- mean(LloydS$"Amount Spent")
mu
n <- 30
alpha <- 0.05  # 95% significance level
z.alpha <- qnorm(1 - alpha/2)

for(i in 1:10000){
 xbar <- mean(LloydS$"Amount Spent"[sample(1:N, n)])
 sigma.xbar <- sigma/sqrt(n)
 margin.error <- z.alpha * sigma.xbar
 lower <- xbar - margin.error
 upper <- xbar + margin.error
 if(lower <= mu & mu <= upper) count[i] <- 1
}
mean(count)


########################################
# 8.2 Population Mean: sigma unknown   #
########################################
s <- sd(LloydS$"Amount Spent"[sample(1:N, n)])
sigma.xbar <- s/sqrt(n)


########################################
# 8.3 Determining the sample size      #
########################################
ceiling((z.alpha^2 * sigma^2)/ margin.error)




